@@ -56,6 +56,7 @@ SEXP C_cmiMatrix(SEXP X,SEXP Z,SEXP Diag,SEXP Threads){
  int *cXc=(int*)R_alloc(sizeof(int),2*n*nt);
  int *nzx=(int*)R_alloc(sizeof(int),m);
  //Collapsed state translation matrix
+ //TODO: Rethink that -- maybe we can make this on a fly?
  int *xz2z=(int*)R_alloc(sizeof(int),n*m);
  double *score=REAL(Ans);
 
@@ -98,3 +99,53 @@ SEXP C_cmiMatrix(SEXP X,SEXP Z,SEXP Diag,SEXP Threads){
  return(Ans);
 }
 
+SEXP C_cmiMatrix2(SEXP X,SEXP Y,SEXP Threads){
+ int n,m,ny,*y,*nx,**x,nt;
+ struct ht **hta;
+ prepareInput(X,Y,R_NilValue,Threads,&hta,&n,&m,NULL,&y,&ny,&x,&nx,&nt);
+
+ int *cXZc=(int*)R_alloc(sizeof(int),n*nt),
+  *cYZc=(int*)R_alloc(sizeof(int),n*nt),
+  *cY=(int*)R_alloc(sizeof(int),n),
+  *cZc=(int*)R_alloc(sizeof(int),n*nt),
+  *yzc=(int*)R_alloc(sizeof(int),n*nt),
+  *xzc=(int*)R_alloc(sizeof(int),n*nt),
+  *yz2zc=(int*)R_alloc(sizeof(int),n*nt);
+
+
+ for(int e=0;e<ny;e++) cY[e]=0;
+ for(int e=0;e<n;e++) cY[y[e]-1]++;
+
+ SEXP Ans=PROTECT(allocMatrix(REALSXP,m,m));
+ double *score=REAL(Ans);
+
+ #pragma omp parallel num_threads(nt)
+ {
+  int tn=omp_get_thread_num(),*cXZ=cXZc+(tn*n),*xz=xzc+(tn*n),
+      *cYZ=cYZc+(tn*n),*yz=yzc+(tn*n),*yz2z=yz2zc+(tn*n),*cZ=cZc+(tn*n);
+  struct ht *ht=hta[tn];
+  #pragma omp for
+  for(int ez=0;ez<m;ez++){
+   int nyz=fillHt(ht,n,ny,y,nx[ez],x[ez],yz,NULL,cZ,1);
+   mixCountsHt(ht,cYZ);
+   transHt(ht,NULL,yz2z);
+   for(int e=0;e<m;e++) if(ez!=e) {
+    int nxz=fillHt(ht,n,nx[e],x[e],nx[ez],x[ez],xz,NULL,NULL,1);
+    fillHt(ht,n,nxz,xz,nyz,yz,NULL,cXZ,NULL,0);
+    score[ez*m+e]=cmiHt(ht,cXZ,cYZ,yz2z,cZ);
+   } else score[e*m+e]=0.;
+  }
+ }
+
+ //Copy attribute names into both dimensions
+ if(isFrame(X)){
+  SEXP dimnames=PROTECT(allocVector(VECSXP,2));
+  SET_VECTOR_ELT(dimnames,0,getAttrib(X,R_NamesSymbol));
+  SET_VECTOR_ELT(dimnames,1,getAttrib(X,R_NamesSymbol));
+  setAttrib(Ans,R_DimNamesSymbol,dimnames);
+  UNPROTECT(1);
+ }
+ 
+ UNPROTECT(1);
+ return(Ans);
+}
