@@ -82,7 +82,7 @@ SEXP C_tri(SEXP X,SEXP Threads){
   }
 
   int *cC=cA,*cAB=cB;
-  int oa=-1,ob=-1,nab;
+  int oa=-1,ob=-1,nab=0; //Not needed, but silences GCC warning
   //Second step; use I(A;B;C)=I(A;C)+I(B;C)-I(AB;C)
   // first two from MI cache, last by holding AB mix
   #pragma omp for
